summaryrefslogtreecommitdiff
authorJian Xu <jian.xu@amlogic.com>2016-07-05 05:29:53 (GMT)
committer Jian Xu <jian.xu@amlogic.com>2016-07-05 05:29:58 (GMT)
commit7569a0672512b05eb6c8d0e8d413524694bdad46 (patch)
tree2824050fe6f9d357bdfb87abd1a2f148d6e40267
parent0f3fb754c51196651c6bb6ef4fa72d06f6ffb789 (diff)
downloadaudio-7569a0672512b05eb6c8d0e8d413524694bdad46.zip
audio-7569a0672512b05eb6c8d0e8d413524694bdad46.tar.gz
audio-7569a0672512b05eb6c8d0e8d413524694bdad46.tar.bz2
PD#124235: audio: only clear the alsa pause status
when other stream is active to avoid pause/resume noise Change-Id: If6de3086655ca5fb11da016735e6b8f53151757c
Diffstat
-rw-r--r--audio_hw.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/audio_hw.c b/audio_hw.c
index 645f6bd..e89d11c 100644
--- a/audio_hw.c
+++ b/audio_hw.c
@@ -956,8 +956,8 @@ static int do_output_standby(struct aml_stream_out *out)
}
if (adev->hwsync_output == out) {
//here to check if hwsync in pause status,if that,chear the status
-//to release the sound card to other output stream
- if (out->pause_status == true) {
+//to release the sound card to other active output stream
+ if (out->pause_status == true && adev->active_output_count > 0) {
if (pcm_is_ready(out->pcm)) {
int r = pcm_ioctl(out->pcm, SNDRV_PCM_IOCTL_PAUSE, 0);
if (r < 0) {